@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.71.2.3 2004/09/22 14:31:28 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.71.2.5 2004/11/25 08:59:45 fuyu Exp $
  */
 
 #include "config.h"
@@ -1628,6 +1628,7 @@ ochusha_thread_2ch_get_url_for_response(OchushaBBSThread *thread, int from,
     case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
     case OCHUSHA_BBS_TYPE_2CH_HEADLINE:
     case OCHUSHA_BBS_TYPE_2CHLIKE_EUCJP:
+    case OCHUSHA_BBS_TYPE_2CH_BE:
       {
 	if (from >= to)
 	  snprintf(url, PATH_MAX, "../test/read.cgi/%s/%s/%d",
@@ -1784,7 +1785,7 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
   if (query == NULL)
     goto error_exit;
 
-  post_result = ochusha_utils_2ch_try_post(broker, thread->board, query);
+  post_result = ochusha_utils_2ch_try_post(broker, thread->board, query, key);
   if (post_result == OCHUSHA_UTILS_2CH_POST_NO_COOKIE)
     {
       if (ochusha_board_2ch_get_cookie(board_2ch) != NULL)
@@ -1799,7 +1800,7 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
 	    }
 	  sleep(10);
 	  post_result = ochusha_utils_2ch_try_post(broker, thread->board,
-						   query);
+						   query, key);
 	}
       else
 	{
@@ -1812,7 +1813,8 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
     {
       /* XXX: äݤΤȤͭʤΤ֡ */
       sleep(30);
-      post_result = ochusha_utils_2ch_try_post(broker, thread->board, query);
+      post_result
+	= ochusha_utils_2ch_try_post(broker, thread->board, query, key);
     }
 #endif
 
