@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.40.2.9 2004/09/22 14:31:28 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.40.2.11 2004/11/25 08:59:46 fuyu Exp $
  */
 
 #include "config.h"
@@ -1042,9 +1042,11 @@ ochusha_utils_2ch_analyze_bbsmenu(OchushaBBSTable *table,
 
 OchushaUtils2chPostResult
 ochusha_utils_2ch_try_post(OchushaNetworkBroker *broker,
-			   OchushaBulletinBoard *board, const char *message)
+			   OchushaBulletinBoard *board,
+			   const char *message, const char *key)
 {
   char url[PATH_MAX];
+  char cookie_buf[4096];
   const char *cookie;
   const char *new_cookie = NULL;
   OchushaBoard2ch *board_2ch;
@@ -1060,6 +1062,7 @@ ochusha_utils_2ch_try_post(OchushaNetworkBroker *broker,
     case OCHUSHA_BBS_TYPE_2CH:
     case OCHUSHA_BBS_TYPE_2CHLIKE_EUCJP:
     case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
+    case OCHUSHA_BBS_TYPE_2CH_BE:
       result = snprintf(url, PATH_MAX, "http://%s%stest/bbs.cgi",
 			ochusha_bulletin_board_get_server(board),
 			ochusha_bulletin_board_get_base_path(board));
@@ -1071,7 +1074,14 @@ ochusha_utils_2ch_try_post(OchushaNetworkBroker *broker,
       break;
 
     case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
-      result = snprintf(url, PATH_MAX, "http://%s/bbs/write.cgi",
+      result = snprintf(url, PATH_MAX, "http://%s/bbs/write.cgi%s%s/%s/",
+			ochusha_bulletin_board_get_server(board),
+			ochusha_bulletin_board_get_base_path(board),
+			ochusha_bulletin_board_get_id(board), key);
+      break;
+
+    case OCHUSHA_BBS_TYPE_MITINOKU:
+      result = snprintf(url, PATH_MAX, "http://%s/bbs.cgi",
 			ochusha_bulletin_board_get_server(board));
       break;
 
@@ -1082,6 +1092,18 @@ ochusha_utils_2ch_try_post(OchushaNetworkBroker *broker,
 
   board_2ch = OCHUSHA_BOARD_2CH(board);
   cookie = ochusha_board_2ch_get_cookie(board_2ch);
+  if (board->bbs_type == OCHUSHA_BBS_TYPE_2CH_BE)
+    {
+      if (broker->config->session_id_2ch_be == NULL)
+	return OCHUSHA_UTILS_2CH_POST_FAILURE;
+
+      if (cookie != NULL)
+	snprintf(cookie_buf, 4096, "%s %s ;",
+		 broker->config->session_id_2ch_be, cookie);
+      else
+	snprintf(cookie_buf, 4096, "%s", broker->config->session_id_2ch_be);
+      cookie = cookie_buf;
+    }
   post_result = ochusha_network_broker_try_post(broker, url,
 				ochusha_bulletin_board_get_server(board),
 				ochusha_bulletin_board_get_base_url(board),
@@ -1370,3 +1392,155 @@ ochusha_utils_2ch_logout(OchushaConfig *config)
       config->session_id_2ch = NULL;
     }
 }
+
+
+void
+ochusha_utils_2ch_be_login(OchushaConfig *config, OchushaNetworkBroker *broker,
+			   const char *user_id, const char *passwd)
+{
+  char content_body[4096];
+  OchushaNetworkBrokerPostStatus post_status;
+  char *session_id = NULL;
+  gboolean post_result;
+  char *server;
+#if 1
+  char *id;
+  char *pw;
+#endif
+
+  if (config->session_id_2ch_be != NULL)
+    {
+      G_FREE(config->session_id_2ch_be);
+      config->session_id_2ch_be = NULL;
+    }
+
+  g_return_if_fail(OCHUSHA_IS_NETWORK_BROKER(broker));
+  g_return_if_fail(user_id != NULL && passwd != NULL);
+
+  if (config->login_2ch_be_url == NULL)
+    config->login_2ch_be_url = G_STRDUP(OCHUSHA_2CH_BE_LOGIN_URL);
+
+  server = ochusha_utils_url_extract_http_server(config->login_2ch_be_url);
+  g_return_if_fail(server != NULL);
+
+#if 1
+  id = ochusha_utils_url_encode_string(user_id);
+  g_return_if_fail(id != NULL);
+
+  pw = ochusha_utils_url_encode_string(passwd);
+  g_return_if_fail(pw != NULL);
+
+  snprintf(content_body, 4096, "submit=%%C5%%D0%%CF%%BF&m=%s&p=%s", id, pw);
+
+  G_FREE(id);
+  G_FREE(pw);
+#else
+  snprintf(content_body, 4096,
+	   "submit=%%C5%%D0%%CF%%BF&m=%s&p=%s", user_id, passwd);
+#endif
+  post_result = ochusha_network_broker_try_post(broker,
+						config->login_2ch_be_url,
+						server,
+						config->login_2ch_be_url,
+						NULL, content_body,
+						&post_status);
+
+  G_FREE(server);
+
+  if (post_result)
+    {
+#if DEBUG_LOGIN
+      gchar message[4096];
+      snprintf(message, 4096, _("2ch Be login Status: %d\n"),
+	       post_status.status_code);
+      ochusha_network_broker_output_log(broker, message);
+
+      if (post_status.body != NULL)
+	{
+	  iconv_t converter = iconv_open("UTF-8//IGNORE", "EUC-JP");
+	  if (converter != (iconv_t)-1)
+	    {
+	      gchar *body_utf8 = convert_string(converter, NULL,
+						post_status.body, -1);
+	      if (body_utf8 != NULL)
+		{
+		  ochusha_network_broker_output_log(broker,
+						    "Result-Body: ");
+		  ochusha_network_broker_output_log(broker, body_utf8);
+		  ochusha_network_broker_output_log(broker, "\n");
+		  G_FREE(body_utf8);
+		}
+	      else
+		{
+		  ochusha_network_broker_output_log(broker,
+						    "iconv_failed.\n");
+		}
+	      iconv_close(converter);
+	    }
+	  else
+	    {
+	      ochusha_network_broker_output_log(broker,
+						"iconv_open failed.\n");
+	    }
+	}
+#endif
+
+      if (post_status.status_code == 200 && post_status.body != NULL)
+	{
+	  const char *mdmd = strstr(post_status.body, "MDMD=");
+	  const char *dmdm = strstr(post_status.body, "DMDM=");
+	  if (mdmd != NULL && dmdm != NULL)
+	    {
+	      const char *mdmd_end = strchr(mdmd, ';');
+	      const char *dmdm_end = NULL;
+	      dmdm = strstr(dmdm, "escape('");
+	      if (dmdm != NULL)
+		{
+		  dmdm += 8;
+		  dmdm_end = strchr(dmdm, '\'');
+		}
+	      if (mdmd_end != NULL && dmdm_end != NULL)
+		{
+		  char cookie_buf[4096];
+		  char *mdmd_cookie = G_STRNDUP(mdmd, mdmd_end - mdmd + 1);
+		  char *dmdm_value = G_STRNDUP(dmdm, dmdm_end - dmdm);
+		  snprintf(cookie_buf, 4096, "%s DMDM=%s ;",
+			   mdmd_cookie, dmdm_value);
+		  G_FREE(mdmd_cookie);
+		  G_FREE(dmdm_value);
+		  session_id = G_STRDUP(cookie_buf);
+#if DEBUG_LOGIN
+		  ochusha_network_broker_output_log(broker,
+						    "2ch Be Cookie: ");
+		  ochusha_network_broker_output_log(broker, session_id);
+		  ochusha_network_broker_output_log(broker, "\n");
+#endif
+		}
+	    }
+#if DEBUG_LOGIN
+	  if (session_id == NULL)
+	    ochusha_network_broker_output_log(broker,
+					      "Cannot find 2ch Be Cookie.\n");
+#endif
+	}
+    }
+
+  if (post_status.body != NULL)
+    G_FREE(post_status.body);
+
+  if (post_status.set_cookie != NULL)
+    G_FREE(post_status.set_cookie);
+
+  config->session_id_2ch_be = session_id;
+}
+
+
+void
+ochusha_utils_2ch_be_logout(OchushaConfig *config)
+{
+  if (config->session_id_2ch_be != NULL)
+    {
+      G_FREE(config->session_id_2ch_be);
+      config->session_id_2ch_be = NULL;
+    }
+}
